# Copyright (c) 2000-2013, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%if "%{?rhel}" == "6"
%bcond_without repolib
%else
%bcond_with repolib
%endif

%define reltag _redhat_2
%global namedreltag -redhat-2
%global namedversion %{version}%{?namedreltag}

Name:           h2database
Version:        1.3.168
Release:        3%{?reltag}%{?dist}
Epoch:          0
Summary:        Java SQL database
Group:          Development/Java
License:        MPL/EPL
URL:            http://www.h2database.com/html/main.html
%if 0
svn -q export -r 4337 http://h2database.googlecode.com/svn/tags/version-1.3.168/h2 h2 && tar cjf h2-1.3.168.tar.bz2 h2
%endif
Source0:        h2-1.3.168.tar.bz2
Patch0:         h2database-pom.patch
Patch1:         h2database-build.patch
Patch2:         h2database-dictionary.patch
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires:       jpackage-utils
%if 0
Requires:       lucene-core >= 0:3.0.2
Requires:       org.osgi.core >= 0:1.2.0
Requires:       servlet_api
Requires:       slf4j >= 0:1.6.0
%endif
BuildRequires:  java-devel
BuildRequires:  jboss-parent
BuildRequires:  jpackage-utils
BuildRequires:  org.osgi.core >= 0:1.2.0
BuildRequires:  lucene-core >= 0:3.0.2
%if %with repolib
BuildRequires:  maven-deploy-plugin
%endif
BuildRequires:  servlet_api
BuildRequires:  slf4j >= 0:1.6.0
%if 0
BuildRequires:  %{_bindir}/soffice
BuildRequires:  %{_bindir}/Xvfb
BuildRequires:  %{_bindir}/xauth
%endif
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Welcome to H2, the Java SQL database. The main features of 
H2 are:
* Very fast, open source, JDBC API
* Embedded and server modes; in-memory databases
* Browser based Console application
* Small footprint: around 1 MB jar file size 

%package javadoc
Summary:        Javadoc for h2
Group:          Documentation
Requires:       jpackage-utils

%description javadoc
%{summary}.

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q -n h2
%patch0 -p1 -b .sav0
%patch1 -p1 -b .sav1
%patch2 -p1 -b .sav2

# FIXME: allows easy servlet upgrade
%{__rm} src/test/org/h2/test/unit/TestServlet.java

%{_bindir}/find -type f -name "*.exe" | %{_bindir}/xargs -t %{__rm}
%{_bindir}/find -type f -name "*.dll" | %{_bindir}/xargs -t %{__rm}
%{_bindir}/find -type f -name "*.jar" | %{_bindir}/xargs -t %{__rm}

%{__mkdir} ext
pushd ext
%{__ln_s} `%{_bindir}/build-classpath servlet_api` servlet-api-2.4.jar
%{__ln_s} `%{_bindir}/build-classpath lucene-core` lucene-core-3.0.2.jar
%{__ln_s} `%{_bindir}/build-classpath slf4j-api` slf4j-api-1.6.0.jar
%{__ln_s} `%{_bindir}/build-classpath org.osgi.core` org.osgi.core-1.2.0.jar
popd

%{__perl} -pi -e 's|BUILD_VENDOR_AND_VERSION = null|BUILD_VENDOR_AND_VERSION = "%{namedreltag}"|g;' src/main/org/h2/engine/Constants.java
%{__perl} -p -e 's|\@version\@|%{namedversion}|g;' src/installer/pom-template.xml > h2-%{namedversion}.pom

%build
# FIXME: patch backup breaks build (javadoc)
%{_bindir}/find -type f -name '*.sav*' | %{_bindir}/xargs -t %{__rm} -f

export CLASSPATH=
export JAVA_HOME=%{java_home}
./build.sh -Dlucene=3 clean compile installer mavenDeployCentral

%{jar} ufm bin/h2-%{namedversion}.jar /dev/null
%{jar} ufm bin/h2-%{namedversion}-javadoc.jar /dev/null
%{jar} ufm bin/h2-%{namedversion}-sources.jar /dev/null

%install
%{__rm} -rf %{buildroot}

# jar
%{__mkdir_p} %{buildroot}%{_javadir}
%{__cp} -p bin/h2-%{namedversion}.jar %{buildroot}%{_javadir}/h2-%{namedversion}.jar
%{__cp} -p bin/h2-%{namedversion}-javadoc.jar %{buildroot}%{_javadir}/h2-%{namedversion}-javadoc.jar
%{__cp} -p bin/h2-%{namedversion}-sources.jar %{buildroot}%{_javadir}/h2-%{namedversion}-sources.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{namedversion}*; do %{__ln_s} ${jar} ${jar/-%{namedversion}/}; done)

# pom
%{__mkdir_p} %{buildroot}%{_mavenpomdir}
%{__cp} -p h2-%{namedversion}.pom %{buildroot}%{_mavenpomdir}/JPP-h2.pom
%add_to_maven_depmap com.h2database h2 %{namedversion} JPP h2
if [ "%{name}" != "h2" ]; then
    %{__mv} %{buildroot}%{_mavendepmapfragdir}/%{name} %{buildroot}%{_mavendepmapfragdir}/h2
fi

%{__mkdir_p} %{buildroot}%{_javadocdir}/h2-%{namedversion}
%{__cp} -pr docs/javadoc/* %{buildroot}%{_javadocdir}/h2-%{namedversion}
%{__ln_s} h2-%{namedversion} %{buildroot}%{_javadocdir}/h2

%if %with repolib
export MAVEN_REPO_LOCAL=`pwd`/.m2/repository
export URL=file://%{buildroot}%{_javadir}/repository.jboss.com/maven2-brew
%{_bindir}/mvn-jpp -e -Dmaven.repo.local=${MAVEN_REPO_LOCAL} deploy:deploy-file -Dfile=%{buildroot}%{_javadir}/h2-%{namedversion}.jar -DpomFile=%{buildroot}%{_mavenpomdir}/JPP-h2.pom -Durl=${URL} \
-DrepositoryId=remote-repository -Djavadoc=%{buildroot}%{_javadir}/h2-%{namedversion}-javadoc.jar -Dsources=%{buildroot}%{_javadir}/h2-%{namedversion}-sources.jar
pushd %{buildroot}%{_javadir}/repository.jboss.com
baddirs=`%{_bindir}/find -type d \( -name "[0-9]*" -and -not -name %{namedversion} \)`
for baddir in ${baddirs}; do
    badver=`/bin/basename ${baddir} | %{__sed} "s/\./\\\./g;"`
    %{__mv} ${baddir}/* `/bin/echo ${baddir} | %{__sed} "s/${badver}/%{namedversion}/g;"`/ && %{__rm} -r ${baddir}/
done
popd
%endif

%clean
%{__rm} -rf %{buildroot}
%{__rm} -rf ${RPM_BUILD_DIR}/h2web

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%{_javadir}/h2-%{namedversion}.jar
%{_javadir}/h2.jar
%{_javadir}/h2-%{namedversion}-sources.jar
%{_javadir}/h2-sources.jar
%{_mavenpomdir}/JPP-h2.pom
%{_mavendepmapfragdir}/h2

%files javadoc
%defattr(644,root,root,755)
%{_javadocdir}/h2-%{namedversion}
%{_javadocdir}/h2
%{_javadir}/h2-%{namedversion}-javadoc.jar
%{_javadir}/h2-javadoc.jar

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}
%{_javadir}/repository.jboss.com
%endif

%changelog
* Mon Mar 26 2013 David Walluck <dwalluck@redhat.com> 0:1.3.168-3
- fix version
- update pom for EAP 6.1

* Mon Aug 27 2012 David Walluck <dwalluck@redhat.com> 0:1.3.168-2
- use lucene 3
- set version to _redhat_1 via patch

* Thu Aug 16 2012 David Walluck <dwalluck@redhat.com> 0:1.3.168-1
- 1.3.168
- update pom patch
- add workaround for deploy bug
- use single deploy command

* Tue Aug 14 2012 Fernando Nasser <fnasser@redhat.com> - 0:1.3.161-0.5_redhat_2.3
- Rebuild unsigned

* Thu Jul 19 2012 Fernando Nasser <fnasser@redhat.com> - 0:1.3.161-0.5_redhat_1.2
- Rebuild using cache signing

* Thu Jul 19 2012 Fernando Nasser <fnasser@redhat.com> - 0:1.3.161-0.5_redhat_1.1
- Rebuild using cache signing

* Mon Jun 04 2012 David Walluck <dwalluck@redhat.com> 0:1.3.161-0.5
- install javadoc jar (in javadoc pkg) and sources jar (in main pkg)
- perform full build

* Mon Jun 04 2012 David Walluck <dwalluck@redhat.com> 0:1.3.161-0.4
- add workaround to fix invalid jar manifests (resolves JBPAPP-9189)

* Tue Apr 17 2012 David Walluck <dwalluck@redhat.com> 0:1.3.161-0.3
- update pom
- remove .dll files
- remove .exe files

* Mon Mar 26 2012 Fernando Nasser <fnasser@redhat.com> - 0:1.3.161-0.2_redhat_1.1
- Rebuild using cache signing

* Fri Dec 02 2011 David Walluck <dwalluck@redhat.com> 0:1.3.161-0.2
- remove optional Requires (that are not in POM)
- add release tag to from POM to RPM Release tag

* Fri Dec 02 2011 David Walluck <dwalluck@redhat.com> 0:1.3.161-0.1
- 1.3.161

* Tue Nov 29 2011 David Walluck <dwalluck@redhat.com> 0:1.2.147-0.1
- 1.2.147
- use h2 name
- remove buildmagic repolib from this branch

* Mon Sep 12 2011 David Walluck <dwalluck@redhat.com> 0:1.2.145-2.2
- add pom patch

* Mon Sep 12 2011 David Walluck <dwalluck@redhat.com> 0:1.2.145-2.1
- use org.osgi.core, not felix
- fix servlet-api symlink
- fix slf4j symlink
- fix ant call
- fix 'mvn deploy:deploy-file call and args
- exclude javadoc dir from repolib files
- switch back to standard repolib location
- fail if ant would have tried to go online to get jars

* Fri Nov 12 2010 David Walluck <dwalluck@redhat.com> 0:1.2.145-2
- add maven repo
- fix repolib

* Fri Nov 12 2010 David Walluck <dwalluck@redhat.com> 0:1.2.145-1
- 1.2.145
- install bundled pom
- use servlet_2_5_api

* Fri Sep 24 2010 Ralph Apel <r.apel@r-apel.de> 1.1.119-1
- First release
